/**
 * HTTP header `Link` entry.
 */
export type HTTPHeaderLinkEntry = [
    uri: string,
    parameters: {
        [key: string]: string;
    }
];
/**
 * Handle the HTTP header `Link` according to the specification RFC 8288.
 */
export declare class HTTPHeaderLink {
    #private;
    get [Symbol.toStringTag](): string;
    /**
     * @param {string | Headers | HTTPHeaderLink | HTTPHeaderLinkEntry[] | Response} [input] Input.
     */
    constructor(input?: string | Headers | HTTPHeaderLink | HTTPHeaderLinkEntry[] | Response);
    /**
     * Add entries.
     * @param {string | Headers | HTTPHeaderLink | HTTPHeaderLinkEntry[] | Response} input Input.
     * @returns {this}
     */
    add(input: string | Headers | HTTPHeaderLink | HTTPHeaderLinkEntry[] | Response): this;
    /**
     * Return all of the entries.
     * @returns {HTTPHeaderLinkEntry[]} Entries.
     */
    entries(): HTTPHeaderLinkEntry[];
    /**
     * Get entries by parameter.
     * @param {string} key Key of the parameter.
     * @param {string} value Value of the parameter.
     * @returns {HTTPHeaderLinkEntry[]} Entries.
     */
    getByParameter(key: string, value: string): HTTPHeaderLinkEntry[];
    /**
     * Get entries by parameter `rel`.
     * @param {string} value Value of the parameter `rel`.
     * @returns {HTTPHeaderLinkEntry[]} Entries.
     */
    getByRel(value: string): HTTPHeaderLinkEntry[];
    /**
     * Whether have entries that match parameter.
     * @param {string} key Key of the parameter.
     * @param {string} value Value of the parameter.
     * @returns {boolean} Result.
     */
    hasParameter(key: string, value: string): boolean;
    /**
     * Stringify entries.
     * @returns {string} Stringified entries.
     */
    toString(): string;
    /**
     * Parse the HTTP header `Link` according to the specification RFC 8288.
     * @param {string | Headers | HTTPHeaderLink | Response} input Input.
     * @returns {HTTPHeaderLink}
     */
    static parse(input: string | Headers | HTTPHeaderLink | Response): HTTPHeaderLink;
    /**
     * Stringify as the HTTP header `Link` according to the specification RFC 8288.
     * @param {HTTPHeaderLinkEntry[]} input Input.
     * @returns {string}
     */
    static stringify(input: HTTPHeaderLinkEntry[]): string;
}
export default HTTPHeaderLink;
//# sourceMappingURL=mod.d.ts.map